@@ -232,9 +232,8 @@ class CLIDriver(object):
         if sys.version_info[0] < 3 or \
                 (sys.version_info[0] == 3 and sys.version_info[1] < 6):
             LOG.warn('You are running the CDP CLI under Python %s. The CDP CLI '
-                     'will require Python 3.6 or higher starting in '
-                     'January 2021. '
-                     'Please upgrade now!', sys.version)
+                     'now requires Python 3.6 or higher. Please upgrade now to '
+                     'avoid CLI errors.', sys.version)
 
     def _warn_for_non_public_release(self):
         if RELEASE != 'PUBLIC':
